#!/bin/bash
#

# buildBoost.sh <opt|debug|prof>

extraqual=${1}

basequal=gcc46
vers=v1_47_0
bvers=boost_1_47_0

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extra_command="variant=release"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extra_command="variant=debug"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extra_command="variant=profile"
else
   echo "ERROR: please define the extra qualifier"
   echo "USAGE: buildBoost.sh <opt|debug|prof>"
   exit 1
fi

echo "compiling for ${fullqual}"


source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
boostdir=${PRODUCTS}/boost/${vers}/${flvr}-${qualdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc v4_6_1
setup gcc v4_6_1
gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.6" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

echo "Building boost in ${boostdir}"

mkdir -p ${boostdir}/build
if [ ! -d ${boostdir}/build ]
then
   echo "ERROR: failed to create ${boostdir}/build"
   exit 1
fi

set -x

cd ${boostdir}/build
tar -xzf ${PRODUCTS}/boost/${vers}/source/${bvers}.tar.gz
cd ${boostdir}/build/${bvers}

./bootstrap.sh --prefix=${boostdir} --without-icu --without-libraries=python,mpi
./bjam --debug-building "${extra_command}"
./bjam --debug-building  "${extra_command}" install

set +x

if [ ! -d ${boostdir}/lib ]
then
   echo "ERROR: failed to create ${boostdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building boost ${vers}"
echo "Declaring boost ${vers} ${flvr} ${fullqual}"
if [ ${OS} = "Darwin" ]
then
   ups declare boost ${vers} -r boost/${vers} -2 -m boost.table -q ${fullqual}
else 
   ups declare boost ${vers} -r boost/${vers} -4 -m boost.table -q ${fullqual}
fi
setup boost ${vers} -q ${fullqual}
echo "BOOST_LIB is ${BOOST_LIB}"

exit 0
